﻿using Microsoft.Extensions.Logging;
using SqlSugar;
using System;

namespace Falcon.SugarApi.DatabaseManager
{
    /// <summary>
    /// 数据库上下文基类
    /// </summary>
    public abstract class DbContextBase:SqlSugarClient
    {
        /// <summary>
        /// 保存数据库日志
        /// </summary>
        public ILogger Logger { get; set; }

        /// <summary>
        /// 使用链接配置构造数据库链接
        /// </summary>
        /// <param name="config">数据库配置</param>
        /// <param name="service">服务提供器</param>
        public DbContextBase(ConnectionConfig config,IServiceProvider service) : base(config) {
            this.Logger = service.GetService(typeof(ILogger<>).MakeGenericType(GetType())) as ILogger ?? throw new NullReferenceException("ILogger");
        }

        /// <summary>
        /// 是否能连接到数据库
        /// </summary>
        public bool CanConnection => this.Ado.IsValidConnection();
    }
}
